Compress and decompress barotrauma save files.
Functions
- compress
- Give
directory_path, a path to a decompressed barotrauma save directory, compress it into a new .save file next to the directory. This will fail if the output file already exists. - decompress
- Given
file_path, a path to a .save file, decompress the save into a new directory next to the save file. This will fail if the output directory already exists.